package surfingsafari;

public class Markov {

    private double[] rank;
    private int n;
    private double[][] probabilities;

    public Markov(TransitionMatrix matrix, int numberOfTransitions) {
        probabilities = matrix.getProbabilities();

        this.n = matrix.getN();

        // Create and initialize rank vector.
        rank = new double[n];
        rank[0] = 1.0;
        for (int i = 1; i < rank.length; i++) {
            rank[i] = 0.0;
        } // for

        for (int i = 0; i < numberOfTransitions; i++) {
            double[] newRank = new double[n];

            // Compute dot product of column j of the probabilities matrix
            // with the rank vector
            for (int j = 0; j < n; j++) {
                for (int k = 0; k < n; k++) {
                    newRank[j] += rank[k] * probabilities[k][j];
                } // for
            } // for

            // Copy contents of newRank array to rank array
            for (int j = 0; j < n; j++) {
                rank[j] = newRank[j];
            } // for

        } // for

    } // Markov( TransitionMatrix, int )

    public double[] getRank() {
        return rank;
    } // getRank()
} // Markov
